Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKent Mein <mein@cs.umn.edu>2005-11-22 21:50:03 +0300
committerKent Mein <mein@cs.umn.edu>2005-11-22 21:50:03 +0300
commit00f266c651a52027b662f725d081af6b51aae343 (patch)
tree40fd6d4d9a76f1eddcc63e5af6091c1442922dca /source/blender/blenkernel/BKE_global.h
parentb63e26e109ba8c651ea20f553e3ca8e0604fc73f (diff)
This is a modified version of patch #2995
To enable dynamic tiff support. I had to fix some of the logic in the fileselect box for icons, I also expanded the patch to look in various default locations for a dynamic libtiff.so/libtiff.dll and look at the env variable BF_TIFF_LIB if it can't find it automatically. If unable to load the library it prints a message about setting BF_TIFF_LIB to the console. I haven't been able to test it on a lot of platforms but hopefully it will just work ;) I added the files to scons but have not had a chance to test that as well. Kent
Diffstat (limited to 'source/blender/blenkernel/BKE_global.h')
-rw-r--r--source/blender/blenkernel/BKE_global.h68
1 files changed, 36 insertions, 32 deletions
diff --git a/source/blender/blenkernel/BKE_global.h b/source/blender/blenkernel/BKE_global.h
index 2335510ac2d..6ecd3626993 100644
--- a/source/blender/blenkernel/BKE_global.h
+++ b/source/blender/blenkernel/BKE_global.h
@@ -66,50 +66,51 @@ struct EditMesh;
typedef struct Global {
- /* active pointers */
- struct View3D *vd;
- struct View2D *v2d;
- struct SpaceIpo *sipo;
- struct SpaceButs *buts;
- struct SpaceImage *sima;
- struct SpaceOops *soops;
- struct SpaceSound *ssound;
- struct SpaceAction *saction; /* __NLA */
+ /* active pointers */
+ struct View3D *vd;
+ struct View2D *v2d;
+ struct SpaceIpo *sipo;
+ struct SpaceButs *buts;
+ struct SpaceImage *sima;
+ struct SpaceOops *soops;
+ struct SpaceSound *ssound;
+ struct SpaceAction *saction; /* __NLA */
struct SpaceNla *snla;
- struct Main *main;
- struct Scene *scene; /* denk aan file.c */
- struct bScreen *curscreen;
- struct Object *obedit;
+ struct Main *main;
+ struct Scene *scene; /* denk aan file.c */
+ struct bScreen *curscreen;
+ struct Object *obedit;
char editModeTitleExtra[64];
- /* fonts, allocated global data */
- struct BMF_Font *font, *fonts, *fontss;
+ /* fonts, allocated global data */
+ struct BMF_Font *font, *fonts, *fontss;
- /* strings: lastsaved */
- char ima[160], sce[160], lib[160];
+ /* strings: lastsaved */
+ char ima[160], sce[160], lib[160];
- /* totals */
- short totobj, totlamp, totobjsel, totcurve, totmesh, totbone, totbonesel;
- int totvert, totedge, totface, totvertsel, totedgesel, totfacesel;
+ /* totals */
+ short totobj, totlamp, totobjsel, totcurve, totmesh;
+ short totbone, totbonesel;
+ int totvert, totedge, totface, totvertsel, totedgesel, totfacesel;
- short afbreek, moving;
- short qual, background;
+ short afbreek, moving;
+ short qual, background;
short winpos, displaymode; /* used to be in Render */
/**
* The current version of Blender.
*/
- short version;
+ short version;
short simulf, order, rt;
int f;
- /* Editmode lists */
+ /* Editmode lists */
struct EditMesh *editMesh;
- float textcurs[4][2];
+ float textcurs[4][2];
- /* Frank's variables */
- int save_over;
+ /* Frank's variables */
+ int save_over;
/* Reevan's __NLA variables */
struct ListBase edbo; /* Armature Editmode bones */
@@ -123,8 +124,11 @@ typedef struct Global {
struct VFont *selfont;
struct ListBase ttfdata;
- /* this variable is written to / read from FileGlobal->fileflags */
- int fileflags;
+ /* libtiff flag */
+ int have_libtiff;
+
+ /* this variable is written to / read from FileGlobal->fileflags */
+ int fileflags;
/* save the allowed windowstate of blender when using -W or -w */
int windowstate;
@@ -132,12 +136,12 @@ typedef struct Global {
/* Janco's playing ground */
struct bSoundListener* listener;
- /* Test thingy for Nzc */
+ /* Test thingy for Nzc */
int compat; /* toggle compatibility mode for edge rendering */
int notonlysolid;/* T-> also edge-render transparent faces */
/* confusing... G.f and G.flags */
- int flags;
+ int flags;
} Global;
@@ -185,7 +189,7 @@ typedef struct Global {
#define G_FILE_SHOW_PROFILE (1 << 6)
#define G_FILE_LOCK (1 << 7)
#define G_FILE_SIGN (1 << 8)
-#define G_FILE_PUBLISH (1 << 9)
+#define G_FIle_PUBLISH (1 << 9)
#define G_FILE_NO_UI (1 << 10)
#define G_FILE_GAME_TO_IPO (1 << 11)